glu

package module
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 7, 2025 License: Apache-2.0 Imports: 2 Imported by: 0

README

go-logging-utils (glu)

Overview

A tiny package for Go developers who want prettier logs integrated into their code.

Installation

In your terminal, run:

go get github.com/M4elstr0m/go-logging-utils

Usage

Please refer to the docstrings within the code for now 😉

Credits

M4elstr0m

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Fatal

func Fatal() string

Fatal in red format associated with the name of the function where it is called. For fatal errors

Usage:
 log.Fatal(glu.Fatal()+"It does this")

func Info

func Info() string

Info in green format associated with the name of the function where it is called. For harmless informations

Usage:
 log.Print(glu.Info()+"It does this")

func Warning

func Warning() string

Warning in yellow format associated with the name of the function where it is called. For non-fatal errors

Usage:
 log.Print(glu.Warning()+"It does this")

Types

This section is empty.

Jump to